@@ -5,24 +5,13 @@
 udocker unit tests: UdockerCLI
 """
 
-import sys
-sys.path.append('.')
-sys.path.append('../../')
-
+from unittest import TestCase, main
+from unittest.mock import Mock, patch
 from udocker.config import Config
 from udocker.cmdparser import CmdParser
 from udocker.cli import UdockerCLI
-from unittest import TestCase, main
-try:
-    from unittest.mock import Mock, patch, MagicMock, mock_open
-except ImportError:
-    from mock import Mock, patch, MagicMock, mock_open
-
-if sys.version_info[0] >= 3:
-    BUILTIN = "builtins"
-else:
-    BUILTIN = "__builtin__"
 
+BUILTIN = "builtins"
 BOPEN = BUILTIN + '.open'
 
 
@@ -33,8 +22,9 @@ class UdockerCLITestCase(TestCase):
         Config().getconf()
         Config().conf['hostauth_list'] = ("/etc/passwd", "/etc/group")
         Config().conf['cmd'] = "/bin/bash"
-        Config().conf['cpu_affinity_exec_tools'] = (["numactl", "-C", "%s", "--", ],
-                                                ["taskset", "-c", "%s", ])
+        Config().conf['cpu_affinity_exec_tools'] = \
+            (["numactl", "-C", "%s", "--", ],
+             ["taskset", "-c", "%s", ])
         Config().conf['valid_host_env'] = "HOME"
         Config().conf['username'] = "user"
         Config().conf['userhome'] = "/"
@@ -58,14 +48,14 @@ class UdockerCLITestCase(TestCase):
         """Test01 UdockerCLI() constructor."""
         # Test Config().conf['keystore'] starts with /
         Config().conf['keystore'] = "/xxx"
-        udoc = UdockerCLI(self.local)
+        UdockerCLI(self.local)
         self.assertTrue(mock_dioapi.called)
         self.assertTrue(mock_lfapi.called)
         self.assertTrue(mock_ks.called_with(Config().conf['keystore']))
 
         # Test Config().conf['keystore'] does not starts with /
         Config().conf['keystore'] = "xx"
-        udoc = UdockerCLI(self.local)
+        UdockerCLI(self.local)
         self.assertTrue(mock_ks.called_with(Config().conf['keystore']))
 
     @patch('udocker.cli.FileUtil.isdir')
@@ -350,11 +340,13 @@ class UdockerCLITestCase(TestCase):
         status = udoc.do_load(cmdp)
         self.assertEqual(status, 0)
 
+    @patch('udocker.cli.Msg')
     @patch('udocker.cli.os.path.exists')
     @patch('udocker.cli.LocalFileAPI.save')
     @patch.object(UdockerCLI, '_check_imagespec')
-    def test_13_do_save(self, mock_chkimg, mock_save, mock_exists):
+    def test_13_do_save(self, mock_chkimg, mock_save, mock_exists, mock_msg):
         """Test13 UdockerCLI().do_save()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -459,9 +451,11 @@ class UdockerCLITestCase(TestCase):
         self.assertEqual(status, 0)
         self.assertTrue(mock_impcont.called)
 
+    @patch('udocker.cli.Msg')
     @patch('udocker.cli.ContainerStructure')
-    def test_15_do_export(self, mock_cs):
+    def test_15_do_export(self, mock_cs, mock_msg):
         """Test15 UdockerCLI().do_export()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -539,11 +533,14 @@ class UdockerCLITestCase(TestCase):
         self.assertEqual(status, 0)
         self.assertTrue(mock_clone.called)
 
+    @patch('udocker.cli.Msg')
     @patch('udocker.cli.KeyStore.put')
     @patch('udocker.cli.DockerIoAPI.get_v2_login_token')
     @patch.object(UdockerCLI, '_set_repository')
-    def test_17_do_login(self, mock_setrepo, mock_dioalog, mock_ksput):
+    def test_17_do_login(self, mock_setrepo, mock_dioalog,
+                         mock_ksput, mock_msg):
         """Test17 UdockerCLI().do_login()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -741,6 +738,7 @@ class UdockerCLITestCase(TestCase):
                        mock_msg, mock_exec):
         """Test23 UdockerCLI().do_run()."""
         mock_msg.level = 0
+        mock_pull.return_value = None
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -751,6 +749,7 @@ class UdockerCLITestCase(TestCase):
         argv = ["udocker", "run"]
         cmdp = CmdParser()
         cmdp.parse(argv)
+        mock_pull.return_value = None
         udoc = UdockerCLI(self.local)
         status = udoc.do_run(cmdp)
         self.assertEqual(status, 1)
@@ -758,12 +757,14 @@ class UdockerCLITestCase(TestCase):
         argv = ["udocker", "run", "--location=/tmp/udocker", "ipyrad"]
         cmdp = CmdParser()
         cmdp.parse(argv)
+        mock_pull.return_value = None
         mock_exec.return_value.get_engine.return_value = False
         udoc = UdockerCLI(self.local)
         status = udoc.do_run(cmdp)
         self.assertEqual(status, 1)
         self.assertTrue(mock_exec.return_value.get_engine.called)
 
+        mock_pull.return_value = None
         exeng_patch = patch("udocker.engine.proot.PRootEngine")
         proot = exeng_patch.start()
         mock_proot = Mock()
@@ -772,6 +773,7 @@ class UdockerCLITestCase(TestCase):
         argv = ["udocker", "run", "--location=/tmp/udocker", "ipyrad"]
         cmdp = CmdParser()
         cmdp.parse(argv)
+        mock_pull.return_value = None
         mock_exec.return_value.get_engine.return_value = proot
         proot.run.return_value = 0
         udoc = UdockerCLI(self.local)
@@ -784,6 +786,7 @@ class UdockerCLITestCase(TestCase):
         cmdp = CmdParser()
         cmdp.parse(argv)
         self.local.get_container_id.return_value = ""
+        mock_pull.return_value = None
         mock_exec.return_value.get_engine.return_value = proot
         proot.run.return_value = 0
         mock_chkimg.return_value = ("ipyrad", "latest")
@@ -851,8 +854,10 @@ class UdockerCLITestCase(TestCase):
         self.assertEqual(status, 0)
         exeng_patch.stop()
 
-    def test_26_do_rm(self):
+    @patch('udocker.cli.Msg')
+    def test_26_do_rm(self, mock_msg):
         """Test26 UdockerCLI().do_rm()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -910,9 +915,11 @@ class UdockerCLITestCase(TestCase):
         status = udoc.do_rm(cmdp)
         self.assertEqual(status, 0)
 
+    @patch('udocker.cli.Msg')
     @patch.object(UdockerCLI, '_check_imagespec')
-    def test_27_do_rmi(self, mock_chkimg):
+    def test_27_do_rmi(self, mock_chkimg, mock_msg):
         """Test27 UdockerCLI().do_rmi()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -963,9 +970,11 @@ class UdockerCLITestCase(TestCase):
         self.assertEqual(status, 0)
         self.assertTrue(self.local.del_imagerepo.called)
 
+    @patch('udocker.cli.Msg')
     @patch.object(UdockerCLI, '_check_imagespec')
-    def test_28_do_protect(self, mock_chkimg):
+    def test_28_do_protect(self, mock_chkimg, mock_msg):
         """Test28 UdockerCLI().do_protect()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -1027,9 +1036,11 @@ class UdockerCLITestCase(TestCase):
         status = udoc.do_protect(cmdp)
         self.assertEqual(status, 1)
 
+    @patch('udocker.cli.Msg')
     @patch.object(UdockerCLI, '_check_imagespec')
-    def test_29_do_unprotect(self, mock_chkimg):
+    def test_29_do_unprotect(self, mock_chkimg, mock_msg):
         """Test29 UdockerCLI().do_unprotect()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -1091,8 +1102,10 @@ class UdockerCLITestCase(TestCase):
         status = udoc.do_unprotect(cmdp)
         self.assertEqual(status, 1)
 
-    def test_30_do_name(self):
+    @patch('udocker.cli.Msg')
+    def test_30_do_name(self, mock_msg):
         """Test30 UdockerCLI().do_name()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -1129,8 +1142,10 @@ class UdockerCLITestCase(TestCase):
         status = udoc.do_name(cmdp)
         self.assertEqual(status, 0)
 
-    def test_31_do_rename(self):
+    @patch('udocker.cli.Msg')
+    def test_31_do_rename(self, mock_msg):
         """Test31 UdockerCLI().do_rename()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -1189,8 +1204,10 @@ class UdockerCLITestCase(TestCase):
         self.assertEqual(status, 0)
         self.assertTrue(self.local.set_container_name.call_count, 1)
 
-    def test_32_do_rmname(self):
+    @patch('udocker.cli.Msg')
+    def test_32_do_rmname(self, mock_msg):
         """Test32 UdockerCLI().do_rmname()."""
+        mock_msg.level = 0
         argv = ["udocker", "-h"]
         cmdp = CmdParser()
         cmdp.parse(argv)
@@ -1357,10 +1374,10 @@ class UdockerCLITestCase(TestCase):
     @patch('udocker.cli.NvidiaMode')
     @patch('udocker.cli.FileUtil.rchmod')
     @patch('udocker.cli.Unshare.namespace_exec')
-    @patch('udocker.cli.MountPoint.restore')
-    @patch('udocker.cli.FileBind.restore')
+    @patch('udocker.cli.MountPoint')
+    @patch('udocker.cli.FileBind')
     @patch('udocker.cli.Msg')
-    def test_35_do_setup(self, mock_msg, mock_fbrest, mock_mprest,
+    def test_35_do_setup(self, mock_msg, mock_fb, mock_mp,
                          mock_unshr, mock_furchmod, mock_nv, mock_execm):
         """Test35 UdockerCLI().do_setup()."""
         mock_msg.level = 0
@@ -1396,8 +1413,9 @@ class UdockerCLITestCase(TestCase):
         cmdp.parse(argv)
         self.local.cd_container.return_value = "/ROOT/cont1"
         self.local.isprotected_container.return_value = False
-        mock_fbrest.return_value = None
-        mock_mprest.return_value = None
+        mock_msg.level = 0
+        mock_fb.return_value.restore.return_value = None
+        mock_mp.return_value.restore.return_value = None
         mock_unshr.return_value = None
         mock_furchmod.return_value = None
         mock_nv.return_value.set_mode.return_value = None
@@ -1405,8 +1423,8 @@ class UdockerCLITestCase(TestCase):
         udoc = UdockerCLI(self.local)
         status = udoc.do_setup(cmdp)
         self.assertEqual(status, 0)
-        self.assertTrue(mock_fbrest.called)
-        self.assertTrue(mock_mprest.called)
+        self.assertTrue(mock_fb.return_value.restore.called)
+        self.assertTrue(mock_mp.return_value.restore.called)
         self.assertTrue(mock_unshr.called)
         self.assertTrue(mock_furchmod.called)
         self.assertTrue(mock_nv.return_value.set_mode.called)
@@ -1418,8 +1436,9 @@ class UdockerCLITestCase(TestCase):
         cmdp.parse(argv)
         self.local.cd_container.return_value = "/ROOT/cont1"
         self.local.isprotected_container.return_value = False
-        mock_fbrest.return_value = None
-        mock_mprest.return_value = None
+        mock_msg.level = 0
+        mock_fb.return_value.restore.return_value = None
+        mock_mp.return_value.restore.return_value = None
         mock_unshr.return_value = None
         mock_furchmod.return_value = None
         mock_nv.return_value.set_mode.return_value = None
